<?php
/* $Id: portuguese-iso-8859-15.inc.php,v 2.9 2005/07/29 17:03:20 lem9 Exp $ */

/**
 * Portuguese language file by
 *   Lopo Pizarro <lopopizarro@users.sourceforge.net>
 *   Antnio Raposo <cfmsoft@users.sourceforge.net>
 */

$charset = 'iso-8859-15';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sab');
$month = array('Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d-%B-%Y s %H:%M';

$timespanfmt = '%s dias, %s horas, %s minutos e %s segundos';

$strAPrimaryKey = 'Uma chave primria foi adicionada a %s';
$strAbortedClients = 'Abortado';
$strAbsolutePathToDocSqlDir = 'Introduza o caminho absoluto at  directoria docSQL no Servidor Web';
$strAccessDenied = 'Acesso Negado';
$strAccessDeniedExplanation = 'O phpMyAdmin tentou ligar-se ao servidor MySQL, e o servidor rejeitou a ligao. Verifique o anfitrio, nome de utilizador e palavra-passe no config.inc.php e assegure-se que correspondem  informao fornecida pelo administrador do MySQL.';
$strAction = 'Aces';
$strAddAutoIncrement = 'Adicionar valor AUTO_INCREMENT';
$strAddConstraints = 'Adicionar limitadores';
$strAddDeleteColumn = 'Adicionar/Remover Campos';
$strAddDeleteRow = 'Adicionar/Remover Critrios';
$strAddDropDatabase = 'Adicionar DROP DATABASE';
$strAddIntoComments = 'Adicionar aos comentrios';
$strAddNewField = 'Adiciona novo campo';
$strAddPrivilegesOnDb = 'Adicionar privilgios na base de dados seguinte';
$strAddPrivilegesOnTbl = 'Todos privilgios na tabela seguinte';
$strAddSearchConditions = 'Condio de Pesquisa (Complemento da clusula "where"):';
$strAddToIndex = 'Adicionar ao ndice &nbsp;%s&nbsp;coluna(s)';
$strAddUser = 'Acrescenta um utilizador';
$strAddUserMessage = 'Acrescentou um novo utilizador.';
$strAddedColumnComment = 'Comentrios para coluna adicionados';
$strAddedColumnRelation = 'Relao para a coluna adicionada';
$strAdministration = 'Administrao';
$strAffectedRows = 'Linhas afectadas:';
$strAfter = 'Depois %s';
$strAfterInsertBack = 'Voltar atrs';
$strAfterInsertNewInsert = 'Inserir novo registo';
$strAll = 'Todas';
$strAllTableSameWidth = 'mostrar todas as tabelas com a mesma altura?';
$strAlterOrderBy = 'Alterar a ordem da tabela por';
$strAnIndex = 'Um ndice foi adicionado a %s';
$strAnalyzeTable = 'Analizar tabela';
$strAnd = 'E';
$strAny = 'Todos';
$strAnyHost = 'Qualquer mquina';
$strAnyUser = 'Qualquer utilizador';
$strArabic = 'rabe';
$strArmenian = 'Armnio';
$strAscending = 'Ascendente';
$strAtBeginningOfTable = 'No Incio da Tabela';
$strAtEndOfTable = 'No Fim da Tabela';
$strAttr = 'Atributos';
$strAutodetect = 'Deteco automtica';
$strAutomaticLayout = 'Layout automtico';

$strBack = 'Voltar';
$strBaltic = 'Bltico';
$strBinary = ' Binrio ';
$strBinaryDoNotEdit = ' Binrio - no editar ';
$strBookmarkAllUsers = 'Deixar todos os utilizadores acederem a este marcador';
$strBookmarkDeleted = 'Marcador apagado com sucesso.';
$strBookmarkLabel = 'Etiqueta';
$strBookmarkOptions = 'Opes de Bookmark';
$strBookmarkQuery = 'Comandos SQL marcados';
$strBookmarkThis = 'Marcar este comando SQL';
$strBookmarkView = 'Ver apenas';
$strBrowse = 'Visualiza';
$strBulgarian = 'Blgaro';
$strBzip = '"Compresso bzip"';

$strCSVOptions = 'Opes CSV';
$strCannotLogin = 'No  possvel fazer login no servidor MySQL';
$strCantLoad = 'no  possvel carregar a extenso %s ;<br />verifique a configurao do PHP por favor';
$strCantLoadRecodeIconv = 'No  possvel carregar <i>iconv</i> ou recodificar a extenso necessria para a converso do Mapa de Caracteres, configure o php de modo a permitir utilizar estas extenses ou desligue a converso do mapa de caracteres no phpmyadmin.';
$strCantRenameIdxToPrimary = 'Impossvel renomear ndice para PRIMARY!';
$strCantUseRecodeIconv = 'No  possvel usar <i>iconv</i> nem <i>libiconv</i> nem a funo <i>recode_string</i> enquanto a extenso reportar que est ligada. Confira a configurao do seu php.';
$strCardinality = 'Quantidade';
$strCarriage = 'Fim de linha: \\r';
$strCaseInsensitive = 'Sensvel a maisculas/minculas';
$strCaseSensitive = 'No-sensvel a a maisculas/minculas';
$strCentralEuropean = 'Europeu Central';
$strChange = 'Muda';
$strChangeCopyMode = 'Criar um novo utilizador com os mesmo privilgios e ...';
$strChangeCopyModeCopy = '... manter o antigo.';
$strChangeCopyModeDeleteAndReload = ' ... apagar o antigo das tabelas do utilizador e depois recarregue os privilgios.';
$strChangeCopyModeJustDelete = ' ... apagar o antigo das tabelas do utilizador.';
$strChangeCopyModeRevoke = ' ... revogar todos os privilgios activos do antigo e a seguir apag-lo.';
$strChangeCopyUser = 'Mudar a informao de login / Copiar Utilizador';
$strChangeDisplay = 'Escolha campo para mostrar';
$strChangePassword = 'Alterar a palavra-passe';
$strCharset = 'Mapa de Caractere';
$strCharsetOfFile = 'Configurar o Mapa de Caracteres do ficheiro:';
$strCharsets = 'Mapas de Caracteres';
$strCheckAll = 'Todos';
$strCheckPrivs = 'Verificar Privilgios';
$strCheckPrivsLong = 'Verificar Privilgios para a Base de Dados &quot;%s&quot;.';
$strCheckTable = 'Verificar tabela';
$strChoosePage = 'Escolha uma Pgina para editar';
$strColComFeat = 'Mostrando comentrios das Colunas';
$strColumnNames = 'Nome dos Campos';
$strColumnPrivileges = 'Privilgios especficos da Coluna';
$strCommand = 'Comando';
$strComments = 'Comentrios';
$strCompleteInserts = 'Instruces de insero completas';
$strCompression = 'Compresso';
$strConfigFileError = 'O phpMyAdmin no foi capaz de ler o ficheiro de configurao!<br />Isto pode acontecer se o php encontrar um erro no <i>parsing</i>  ou se no conseguir encontrar o ficheiro.<br />Chame o ficheiro de configurao directamente usando o <i>link</i> a baixo e leia a(s) mensagem(ns) de erro do php. Na maior parte dos casos, trata-se de uma falta de aspas ou de um ponto e vrgula algures.<br />Se receber uma pgina em branco, est tudo correcto.';
$strConfigureTableCoord = 'Configure as cordenadas para a tabela %s';
$strConnections = 'Ligaes';
$strConstraintsForTable = 'Limitadores para a tabela';
$strCookiesRequired = 'O mecanismo de "Cookies" tem de estar ligado a partir deste ponto.';
$strCopyTable = 'Copia tabela para (base-de-dados<b>.</b>tabela):';
$strCopyTableOK = 'Tabela %s copiada para %s.';
$strCopyTableSameNames = 'No  possivel copiar a tabela para o mesmo!';
$strCreate = 'Criar';
$strCreateIndex = 'Criar um ndice com&nbsp;%s&nbsp;coluna(s)';
$strCreateIndexTopic = 'Criar um novo ndice';
$strCreateNewDatabase = 'Criar nova base de dados';
$strCreateNewTable = 'Criar nova tabela na base de dados %s';
$strCreatePage = 'Criar uma Pgina nova';
$strCreatePdfFeat = 'Criao de PDFs';
$strCreationDates = 'Datas de Criao/Actualizao/verificao';
$strCriteria = 'Critrios';
$strCroatian = 'Croata';
$strCzech = 'Checo';
$strCzechSlovak = 'Checo-Eslovaco';

$strDBComment = 'Comentrio da Base de Dados: ';
$strDBGContext = 'Contexto';
$strDBGContextID = 'ID de Contexto';
$strDBGHits = 'Hits';
$strDBGLine = 'Linha';
$strDBGMaxTimeMs = 'Tempo mx, ms';
$strDBGMinTimeMs = 'Tempo min, ms';
$strDBGModule = 'Mdulo';
$strDBGTimePerHitMs = 'Tempo/Hit, ms';
$strDBGTotalTimeMs = 'Tempo total, ms';
$strDanish = 'Dinamarqus';
$strData = 'Dados';
$strDataDict = 'Dicionario de dados';
$strDataOnly = 'Apenas dados';
$strDatabase = 'Base de Dados';
$strDatabaseExportOptions = 'Opes de exportao da Base de Dados';
$strDatabaseHasBeenDropped = 'A base de dados %s foi eliminada.';
$strDatabaseNoTable = 'Esta Base de Dados no contm qualquer tabela!';
$strDatabases = 'Base de Dados';
$strDatabasesDropped = 'As Bases de Dados %s foram apagadas com sucesso.';
$strDatabasesStats = 'Estatsticas das bases de dados';
$strDatabasesStatsDisable = 'Desactivar Estatsticas';
$strDatabasesStatsEnable = 'Activar Estatsticas';
$strDatabasesStatsHeavyTraffic = 'Nota: Activar as estatsticas aqui pode causar um grande volume de trfego entre o servidor web e o de MySQL.';
$strDbPrivileges = 'Privilgios especficos da Base de Dados';
$strDbSpecific = 'Especifico da Base de Dados';
$strDefault = 'Defeito';
$strDelete = 'Apagar';
$strDeleteAndFlush = 'Apagar os utilizadores e recarreguar os privilgios a seguir.';
$strDeleteAndFlushDescr = 'Este  o processo mais limpo, mas recarregar os privilgios poder demorar um pouco.';
$strDeleted = 'Registo eliminado';
$strDeletedRows = 'Linhas apagadas:';
$strDeleting = 'A apagar %s';
$strDescending = 'Descendente';
$strDescription = 'Descrio';
$strDictionary = 'dicionrio';
$strDisabled = 'Desactidado';
$strDisplayFeat = 'Mostrar Caractersticas';
$strDisplayOrder = 'Ordem de visualizao:';
$strDisplayPDF = 'Mostrar o esquema de PDF';
$strDoAQuery = 'Faa uma "pesquisa por formulrio" (caractere universal: "%")';
$strDoYouReally = 'Confirma : ';
$strDocu = 'Documentao';
$strDrop = 'Elimina';
$strDropSelectedDatabases = 'Apagar Bases de Dados selecionada';
$strDropUsersDb = 'Apagar as Bases de Dados que tenham os mesmos nomes que os utilizadores.';
$strDumpSaved = 'O Dump foi gravado para o ficheiro %s.';
$strDumpXRows = 'Exporta %s registos comeando em %s.';
$strDumpingData = 'Extraindo dados da tabela';
$strDynamic = 'dinmico';

$strEdit = 'Edita';
$strEditPDFPages = 'Editar pginas PDF';
$strEditPrivileges = 'Alterar Privilegios';
$strEffective = 'Em uso';
$strEmpty = 'Limpa';
$strEmptyResultSet = 'MySQL no retornou nenhum registo.';
$strEnabled = 'Activado';
$strEnd = 'Fim';
$strEnglish = 'Ingls';
$strEnglishPrivileges = ' Nota: os nomes dos privilgios do MySQL so em Ingls ';
$strError = 'Erro';
$strEstonian = 'Estoniano';
$strExcelEdition = 'Edio Excel';
$strExcelOptions = 'Opes Excel';
$strExecuteBookmarked = 'Executar um query marcado(do marcador)';
$strExplain = 'Explicar SQL';
$strExport = 'Exportar';
$strExtendedInserts = 'Instruces de insero mltiplas';
$strExtra = 'Extra'; // written the same in portuguese

$strFailedAttempts = 'Tentativas falhadas';
$strField = 'Campo';
$strFieldHasBeenDropped = 'O campo %s foi eliminado';
$strFields = 'Qtd Campos';
$strFieldsEmpty = ' Nmero de campos invlido! ';
$strFieldsEnclosedBy = 'Campos delimitados por';
$strFieldsEscapedBy = 'Campos precedidos por';
$strFieldsTerminatedBy = 'Campos terminados por';
$strFileAlreadyExists = 'O ficheiro  %s j existe no servidor, mude o nome do ficheiro ou verifique a opo de substituio (re-escrita).';
$strFileCouldNotBeRead = 'No foi possvel ler o ficheiro';
$strFileNameTemplate = 'Nome do ficheiro modelo';
$strFileNameTemplateHelp = 'Usar __DB__ para nome da Base de Dados, __TABLE__ para nome da tabela e %sany strftime%s opes para especifico do tempo , a extenso ser acrescentada automaticamente. Qualquer outro texto ser preservado.';
$strFileNameTemplateRemember = 'Lembrar-se do modelo';
$strFixed = 'fixo';
$strFlushPrivilegesNote = 'Nota: O phpMyAdmin recebe os privilgios dos utilizadores directamente da tabela de privilgios do MySQL. O contedo destas tabelas pode diferir dos privilgios que o servidor usa se alteraes manuais nele forem feitas. Neste caso, deve  %sreload the privileges%s antes de continuar.';
$strFlushTable = 'Fecha a tabela ("FLUSH")';
$strFormEmpty = 'N de dados insuficiente!\nPreencha todas as opes!';
$strFormat = 'Formato';
$strFullText = 'Texto inteiro';
$strFunction = 'Funes';

$strGenBy = 'Gerado por';
$strGenTime = 'Data de Criao';
$strGeneralRelationFeat = 'Caractersticas gerais de Relao';
$strGeorgian = 'Georgiano';
$strGerman = 'Alemo';
$strGlobal = 'global';  //(same in portuguese)
$strGlobalPrivileges = 'Privilgios Globais';
$strGlobalValue = 'Valor Global';
$strGo = 'Executa';
$strGrantOption = 'Conceder/Grant';
$strGreek = 'Grego';
$strGzip = '"Compresso gzip"';

$strHasBeenAltered = 'foi alterado(a).';
$strHasBeenCreated = 'foi criado(a).';
$strHaveToShow = 'Tem que escolher pelo menos uma coluna para mostrar';
$strHebrew = 'Hebrico';
$strHome = 'Incio';
$strHomepageOfficial = 'Pgina Oficial do phpMyAdmin';
$strHost = 'Mquina';
$strHostEmpty = 'O nome da mquina est vazio!';
$strHungarian = 'Hngaro';

$strId = 'ID'; //(same in portuguese)
$strIdxFulltext = 'Texto Completo';
$strIfYouWish = 'Para carregar apenas algumas colunas da tabela, faa uma lista separada por virgula.';
$strIgnore = 'Ignora';
$strIgnoringFile = 'A ignorar ficheiro %s';
$strImportDocSQL = 'Importar ficheiros docSQL';
$strImportFiles = 'Importar';
$strImportFinished = 'Importar terminada';
$strInUse = 'em uso';
$strIndex = 'ndice';
$strIndexHasBeenDropped = 'O ndice %s foi eliminado';
$strIndexName = 'Nome do ndice&nbsp;:';
$strIndexType = 'Tipo de ndice&nbsp;:';
$strIndexes = 'ndices';
$strInnodbStat = 'Estado da InnoDB';
$strInsecureMySQL = 'O seu ficheiro de configurao contem configuraes (root sem palavra-passe) que correspondem  conta privilegiada por defeito do MySQL. O servidor MySQL est a correr com este valor por defeito, assim aberto a intruses, deveria corrigir este buraco de segurana.';
$strInsert = 'Insere';
$strInsertAsNewRow = 'Insere como novo registo';
$strInsertNewRow = 'Insere novo registo';
$strInsertTextfiles = 'Insere arquivo texto na tabela';
$strInsertedRowId = 'Inserir id de linha:';
$strInsertedRows = 'Registos inseridos :';
$strInstructions = 'Instrues';
$strInternalNotNecessary = '* No  necessria uma relao interna quando tambm j existe na InnoDB.';
$strInternalRelations = 'Relaes internas';

$strJapanese = 'Japons';
$strJumpToDB = 'Saltar para a Base de Dados &quot;%s&quot;.';
$strJustDelete = 'Apagar apenas os utilizadores da tabela de privilgios.';
$strJustDeleteDescr = 'Os utilizadores &quot;deleted&quot; continuaro a conseguir aceder ao servidor at que os privilgios sejam recarregados.';

$strKeepPass = 'Mantendo a palavra-passe ';
$strKeyname = 'Nome do ndice';
$strKill = 'Termina';
$strKorean = 'Coreano';

$strLaTeX = 'LaTeX';  //(same in portuguese)
$strLaTeXOptions = 'Opes LaTeX';
$strLandscape = 'Paisagem/ao baixo';
$strLatexCaption = 'Legenda da tabela';
$strLatexContent = 'Contedo da tabela __TABLE__';
$strLatexContinued = '(continuao)';
$strLatexContinuedCaption = 'Continuao da legenda da tabela';
$strLatexIncludeCaption = 'Incluir a legenda da tabela';
$strLatexStructure = 'estructura da tabela __TABLE__';
$strLengthSet = 'Tamanho/Valores*';
$strLimitNumRows = 'Nmero de registos por pgina';
$strLineFeed = 'Mudana de linha: \\n';
$strLinesTerminatedBy = 'Linhas terminadas por';
$strLinkNotFound = 'Link no encontrado';
$strLinksTo = 'Links para';
$strLithuanian = 'Lituano';
$strLoadExplanation = 'O melhor mtodo  verificado por defeito, mas pode alterar se isto falhar.';
$strLoadMethod = 'Mtodo de carregar(LOAD)';
$strLocalhost = 'Local';
$strLocationTextfile = 'Localizao do arquivo de texto';
$strLogPassword = 'Palavra-passe&nbsp;:';
$strLogServer = 'Servidor';
$strLogUsername = 'Utilizador&nbsp;:';
$strLogin = 'Entrada';
$strLoginInformation = 'Informao de Login ';
$strLogout = 'Sair';

$strMIME_MIMEtype = 'MIME-type';  //(same in portuguese)
$strMIME_available_mime = 'MIME-types disponveis';
$strMIME_available_transform = 'Transformaes disponveis';
$strMIME_description = 'Descrio';
$strMIME_nodescription = 'No h descrio disponvel para esta transformao.<br />Pergunte ao autor, o que %s faz.';
$strMIME_transformation = 'Transformao do navegador';
$strMIME_transformation_note = 'Para uma lista de opes de transformao disponveis e suas transformaes MIME-type , clique em %stransformation descriptions%s';
$strMIME_transformation_options = 'Opes de tranformao';
$strMIME_transformation_options_note = 'Introduza os valores para as opes de transformao a usando este formato: \'a\',\'b\',\'c\'...<br />Se por acaso precisar de inserir um backslash ("\") ou uma pelica ("\'") no meio desses valores, faa-o backslashes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').';
$strMIME_without = 'MIME-types impressos em itlico no tem uma funo de transformao separada';
$strMaximumSize = 'Tamanho mximo: %s%s';
$strModifications = 'Modificaes foram guardadas';
$strModify = 'Modifica';
$strModifyIndexTopic = 'Modificar um ndice';
$strMoreStatusVars = 'Mais variveis de estado';
$strMoveTable = 'Move tabela para (base de dados<b>.</b>tabela):';
$strMoveTableOK = 'A tabela %s foi movida para %s.';
$strMoveTableSameNames = 'No  posivel mover a tabela para o mesmo!';
$strMultilingual = 'multilingua';
$strMustSelectFile = 'Deve selecionar o ficheiro que quer inserir.';
$strMySQLCharset = 'Mapa de Caracteres do mySQL';
$strMySQLReloaded = 'MySQL reiniciado.';
$strMySQLSaid = 'Mensagens do MySQL : ';
$strMySQLServerProcess = 'MySQL %pma_s1% a correr em %pma_s2% como %pma_s3%';
$strMySQLShowProcess = 'Mostra os Processos';
$strMySQLShowStatus = 'Mostra informao do estado do MySQL';
$strMySQLShowVars = 'Mostra as variveis de sistema do MySQL';

$strName = 'Nome';
$strNext = 'Prximo';
$strNo = 'No';
$strNoDatabases = 'Sem bases de dados';
$strNoDatabasesSelected = 'Nenhuma base de dados selecionada.';
$strNoDescription = 'sem Descrio';
$strNoDropDatabases = 'Os comandos "DROP DATABASE" esto inibidos.';
$strNoExplain = 'Saltar Explicar SQL';
$strNoFrames = 'O phpMyAdmin torna-se mais agradvel se usado num browser que suporte <b>frames</b>.';
$strNoIndex = 'Nenhum indce definido!';
$strNoIndexPartsDefined = 'Nenhuma parte do ndice definida!';
$strNoModification = 'Sem alteraes';
$strNoOptions = 'Este formato no tem opes';
$strNoPassword = 'Sem palavra-passe';
$strNoPermission = 'O servidor web no tem permisses para gravar o ficheiro %s.';
$strNoPhp = 'sem cdigo PHP';
$strNoPrivileges = 'Sem Privilgios';
$strNoQuery = 'Nenhum comando SQL encontrado!';
$strNoRights = 'No tem permisses suficientes para aceder aqui, neste momento!';
$strNoSpace = 'No existe espao suficiente para gravar o ficheiro %s.';
$strNoTablesFound = 'Nenhuma tabela encontrada na base de dados';
$strNoUsersFound = 'Nenhum utilizador encontrado.';
$strNoValidateSQL = 'Saltar a validao SQL';
$strNone = 'Nenhum';
$strNotNumber = 'Isto no  um nmero!';
$strNotOK = 'no est OK';
$strNotSet = 'A Tabela <b>%s</b> no foi encontrada ou no foi definida em %s';
$strNull = 'Nulo';
$strNumSearchResultsInTable = '%s resultado(s) na tabela <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)';
$strNumTables = 'Tabelas';

$strOK = 'OK';  //Same in portuguese
$strOftenQuotation = 'Normalmente aspas. OPTIONALLY significa que apenas os campos "char" e "varchar" so delimitados pelo caractere delimitador.';
$strOperations = 'Operaes';
$strOptimizeTable = 'Optimizar tabela';
$strOptionalControls = 'Opcional. Comanda o modo de escrita e leitura dos caracteres especiais.';
$strOptionally = 'OPCIONAL';
$strOr = 'Ou';
$strOverhead = 'Suspenso';
$strOverwriteExisting = 'Substituir o(s) ficheiro(s) existente(s)';

$strPHP40203 = 'Est a usar o PHP 4.2.3, que tem uma grave falha de segurana com a string multi-byte (mbstring). Veja o relatrio de bugs do PHP 19404 - PHP bug report 19404. A utilizao desta verso do PHP com o phpMyAdmin no  recomendada.';
$strPHPVersion = 'verso do PHP';
$strPageNumber = 'Pgina nmero:';
$strPaperSize = 'Tamanho do papel';
$strPartialText = 'Texto parcial';
$strPassword = 'Palavra-passe';
$strPasswordChanged = 'A palavra-passe para %s foi alterada com sucesso.';
$strPasswordEmpty = 'Indique a palavras-passe!';
$strPasswordNotSame = 'As palavras-passe so diferentes!\nLembre-se de confirmar a palavra-passe!';
$strPdfDbSchema = 'Esquema da base de dados "%s" - Pgina %s';
$strPdfInvalidTblName = 'A tabela "%s" no existe!';
$strPdfNoTables = 'Sem tablelas';
$strPerHour = 'por hora';
$strPerMinute = 'por minuto';
$strPerSecond = 'por segundo';
$strPhoneBook = 'lista telefnica';
$strPhp = 'Criar cdigo PHP';
$strPmaDocumentation = 'Documentao do phpMyAdmin';
$strPmaUriError = 'A directiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> TEM que ser definida no ficheiro de configurao!';
$strPortrait = 'Retrato/Ao alto';
$strPos1 = 'Inicio';
$strPrevious = 'Anterior';
$strPrimary = 'Primria';
$strPrimaryKeyHasBeenDropped = 'A chave primria foi eliminada';
$strPrimaryKeyName = 'O nome da chave primria tem de ser... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>tem</b> de ser o nome de e <b>apenas de</b> uma chave primria!)';
$strPrint = 'Imprimir';
$strPrintView = 'Vista de impresso';
$strPrintViewFull = 'Vista de impresso (com texto inteiro)';
$strPrivDescAllPrivileges = 'inclui todos os privilgios excepto Conceo - GRANT.';
$strPrivDescAlter = 'Permite alterar a estrutura de tabelas existentes.';
$strPrivDescCreateDb = 'Permite criar novas Bases de Dados e tabelas.';
$strPrivDescCreateTbl = 'Permite criar novas tabelas.';
$strPrivDescCreateTmpTable = 'Permite criar tabelas temporrias.';
$strPrivDescDelete = 'Permite apagar dados.';
$strPrivDescDropDb = 'Permite apagar Bases de Dados e tabelas.';
$strPrivDescDropTbl = 'Permite apagar Bases de Dados.';
$strPrivDescExecute = 'Permite executar procedimentos armazenados; No tem efeito nesta verso do MySQL.';
$strPrivDescFile = 'Permite importar dados de... e exportar dados para ficheiros.';
$strPrivDescGrant = 'Permite adicionar utilizadores e privilgios sem recarregar a tabela de privilgios.';
$strPrivDescIndex = 'Permite criar e apagar indexes.';
$strPrivDescInsert = 'Permite inserir e substituir dados.';
$strPrivDescMaxConnections = 'Limits the number of new connections the user may open per hour.';
$strPrivDescMaxQuestions = 'Limits the number of queries the user may send to the server per hour.';
$strPrivDescMaxUpdates = 'Limits the number of commands that change any table or database the user may execute per hour.';
$strPrivDescProcess3 = 'Permite eliminar processos de outros utilizadores.';
$strPrivDescProcess4 = 'Permite ver o queries completos na lista de processos.';
$strPrivDescReferences = 'No tem efeito nesta verso do MySQL.';
$strPrivDescSelect = 'Permite ler dados.';
$strPrivDescShowDb = 'D acesso  lista de bases de dados completa.';
$strPrivDescShutdown = 'Permite desligar o servidor.';
$strPrivDescUpdate = 'Permite alterar dados.';
$strPrivDescUsage = 'Sem privilgios.';
$strPrivileges = 'Privilgios';
$strPrivilegesReloaded = 'O privilgios foram recarregados com sucesso.';
$strProcesslist = 'Lista de Processos';
$strPutColNames = 'Coloca os nomes dos compos na primeira linha';

$strQBE = 'Pesquisa por formulrio';
$strQBEDel = 'Elim.';
$strQBEIns = 'Ins.';
$strQueryFrame = 'Janela de Query';
$strQueryOnDb = 'Comando SQL na base de dados <b>%s</b>:';
$strQuerySQLHistory = 'Histrico SQL';
$strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
$strQueryTime = 'O Query demorou %01.4f sec';
$strQueryType = 'Tipo de Query';
$strQueryWindowLock = 'No alterar esta pesquisa de fora da janela';

$strReType = 'Confirma';
$strReceived = 'Recebido';
$strRecords = 'Registos';
$strReferentialIntegrity = 'Verificar Integridade referencial:';
$strRelationNotWorking = 'As Caractersticas adicionais para trabalhar com ligaes entre Tabelas foram desactivadas. Para saber porqu carregue %saqui%s.';
$strRelationView = 'Vista de Relao';
$strRelationalSchema = 'Esquema relacional';
$strRelations = 'Relaes';
$strReloadFailed = 'Reiniciao do MySQL falhou.';
$strReloadMySQL = 'Reiniciar o MySQL';
$strReloadingThePrivileges = 'A recarregar privilgios';
$strRemoveSelectedUsers = 'Remover utilizadores seleccionados';
$strRenameTable = 'Renomeia a tabela para ';
$strRenameTableOK = 'Tabela %s renomeada para %s';
$strRepairTable = 'Reparar tabela';
$strReplace = 'Substituir';
$strReplaceNULLBy = 'Substituir NULL por';
$strReplaceTable = 'Substituir os dados da tabela pelos do arquivo';
$strReset = 'Limpa';
$strResourceLimits = 'Limites do recurso';
$strRevoke = 'Anula';
$strRevokeAndDelete = 'Revogar todos os privilgios dos utilizadores e apag-los a seguir.';
$strRevokeAndDeleteDescr = 'O utilizadores mantero o privilgio de USAGE at que os privilgios sejam recarregados.';
$strRevokeMessage = 'Anulou os privilgios para %s';
$strRowLength = 'Comprim. dos reg.';
$strRowSize = ' Tamanho dos reg.';
$strRows = 'Registos';
$strRowsFrom = 'registos comeando em';
$strRowsModeFlippedHorizontal = 'horizontal (cabealhos rodados)';
$strRowsModeHorizontal = 'horizontal';  // same in portuguese!
$strRowsModeOptions = 'em modo %s com cabealhos repetidos a cada %s clulas';
$strRowsModeVertical = 'vertical';  // same in portuguese!
$strRowsStatistic = 'Estatsticas dos registos';
$strRunQuery = 'Executa Comando SQL';
$strRunSQLQuery = 'Executa comando(s) SQL na base de dados %s';
$strRunning = 'a correr em %s';
$strRussian = 'Russo';

$strSQL = 'SQL';
$strSQLExportType = 'Tipo de Exportao';
$strSQLOptions = 'Opes SQL';
$strSQLParserBugMessage = 'Talvez tenha encontrado um bug no analizador (parser) do SQL. Analise o seu query aprofundadamente, e verifique se as aspas esto correctas e no esto desencontradas. Outra possibilidade de falha  o facto de estar a fazer o upload de um ficheiro com outside binrio, de de uma rea de texto citada. Pode tambm experimentar a sua query na interface da linha de comandos do MySQL. A sada de erro do MySQL abaixo, isto se existir alguma, tambm o poder ajudar a diagnosticar o problema. Se continuar a ter problemas ou se o analisador (parser) falhar onde a interface da linha de comandos tiver sucesso, reduza por favor a entrada do query SQL at aquele que causa o problema, e envie o relatrio de bug com os dados do chunk na seco CUT abaixo:';
$strSQLParserUserError = 'Parece haver um erro no seu query SQL. A sada do servidor MySQL abaixo, isto se existir alguma, tambm o poder ajudar a diagnosticar o problema.';
$strSQLQuery = 'Comando SQL';
$strSQLResult = 'Resultado SQL';
$strSQPBugInvalidIdentifer = 'Identificador invlido';
$strSQPBugUnclosedQuote = 'Aspa no fechada';
$strSQPBugUnknownPunctuation = 'Pontuao desconhecida';
$strSave = 'Guarda';
$strSaveOnServer = 'Gravar no servidor na directoria %s';
$strScaleFactorSmall = 'O factor escala  muito pequeno para encaixar o esquema numa pgina';
$strSearch = 'Pesquisar';
$strSearchFormTitle = 'Pesquisar na Base de Dados';
$strSearchInTables = 'Dentro de Tabela(s):';
$strSearchNeedle = 'Palavra(s) ou valor(es) para pesquisar para (wildcard: "%"):';
$strSearchOption1 = 'pelo menos uma das palavras';
$strSearchOption2 = 'todas as palavras';
$strSearchOption3 = 'a frase exacta';
$strSearchOption4 = 'as regular expression';
$strSearchResultsFor = 'Procurar resultados para "<i>%s</i>" %s:';
$strSearchType = 'Procurar:';
$strSecretRequired = 'O ficheiro de configurao precisa agora de uma frase-passe secreta (blowfish_secret).';
$strSelectADb = 'Por favor seleccione uma base de dados';
$strSelectAll = 'Selecciona Todas';
$strSelectFields = 'Seleccione os campos (no mnimo 1)';
$strSelectNumRows = 'na pesquisa';
$strSelectTables = 'Seleccionar Tabelas';
$strSend = 'envia';
$strSent = 'Enviado';
$strServer = 'Servidor';
$strServerChoice = 'Escolha do Servidor';
$strServerStatus = 'Informao de Runtime';
$strServerStatusUptime = 'Este servidor de mySQL estar a correr h %s. Foi iniciado em/a %s.';
$strServerTabProcesslist = 'Processos';
$strServerTabVariables = 'Variveis';
$strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.';
$strServerVars = 'Variveis do servidor e configuraes';
$strServerVersion = 'Verso do servidor';
$strSessionValue = 'Valor de sesso';
$strSetEnumVal = 'Se o tipo de campo  "enum" ou "set", por favor introduza os valores no seguinte formato: \'a\',\'b\',\'c\'...<br />Se precisar de colocar uma barra invertida ("\") ou um apstrofe ("\'") entre esses valores, coloque uma barra invertida antes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').';
$strShow = 'Mostra';
$strShowAll = 'Mostrar tudo';
$strShowColor = 'Mostrar cr';
$strShowDatadictAs = 'Formato dos dados do dicionrio';
$strShowFullQueries = 'Mostrar queries completos';
$strShowGrid = 'Mostrar grelha';
$strShowPHPInfo = 'Mostra informao do PHP';
$strShowTableDimension = 'Mostrar dimenso das tabelas';
$strShowTables = 'Mostra tabelas';
$strShowThisQuery = ' Mostrar de novo aqui este comando ';
$strShowingRecords = 'Mostrando registos ';
$strSimplifiedChinese = 'Chins Simplificado';
$strSingly = '(A refazer aps inserir/eliminar)';
$strSize = 'Tamanho';
$strSort = 'Ordenao';
$strSortByKey = 'Ordenar por chave';
$strSpaceUsage = 'Espao ocupado';
$strSplitWordsWithSpace = 'As palavras so separadas pelo caracter espao (" ").';
$strStatCheckTime = 'Verificao';
$strStatCreateTime = 'Criao';
$strStatUpdateTime = 'Actualizao';
$strStatement = 'Itens';
$strStatus = 'Estado';
$strStrucCSV = 'Dados CSV';
$strStrucData = 'Estrutura e dados';
$strStrucDrop = 'Adiciona DROP TABLE';
$strStrucExcelCSV = 'dados CSV para MS Excel';
$strStrucOnly = 'Somente estrutura';
$strStructPropose = 'Propor uma estrutura de tabela';
$strStructure = 'Estrutura';
$strSubmit = 'Submete';
$strSuccess = 'O seu comando SQL foi executado com sucesso';
$strSum = 'Soma';
$strSwedish = 'Sueco';
$strSwitchToTable = 'Mudar para a tabela copiada';

$strTable = 'Tabela';
$strTableComments = 'Comentrios da tabela';
$strTableEmpty = 'O nome da tabela est vazio!';
$strTableHasBeenDropped = 'A tabela %s foi eliminada';
$strTableHasBeenEmptied = 'A tabela %s foi limpa';
$strTableHasBeenFlushed = 'A tabela %s foi fechada';
$strTableMaintenance = 'Manuteno da tabela';
$strTableOfContents = 'ndice';
$strTableOptions = 'Opes da tabela';
$strTableStructure = 'Estrutura da tabela';
$strTableType = 'Tipo de tabela';
$strTables = '%s tabela(s)';
$strTblPrivileges = 'Privilgios especficos da tabela';
$strTextAreaLength = ' Devido ao seu tamanho,<br /> este campo pode no ser editvel ';
$strThai = 'Tailands';
$strTheContent = 'O contedo do seu arquivo foi inserido';
$strTheContents = 'O contedo do arquivo substituiu o contedo da tabela que tinha a mesma chave primria ou nica';
$strTheTerminator = 'Terminador de campos.';
$strThisHost = 'Este Anfitrio';
$strThisNotDirectory = 'Isto no era uma directoria';
$strTime = 'Tempo';
$strTotal = 'total';
$strTotalUC = 'Total'; // (same in portuguese)
$strTraditionalChinese = 'Chins Tradicional';
$strTraffic = 'Trfego';
$strTransformation_image_jpeg__inline = 'Mostra uma miniatura clicvel; opes: largura,altura em pixeis (mantm a proporo original)';
$strTransformation_image_jpeg__link = 'Mostra uma ligao para esta imagem (blob download directo , i.e.).';
$strTransformation_image_png__inline = 'Ver imagem/jpeg: inline';
$strTransformation_text_plain__formatted = 'Preserva a formatao original do campo. Sem Escaping.';
$strTruncateQueries = 'Truncar os Queries mostrados';
$strTurkish = 'Turco';
$strType = 'Tipo';

$strUkrainian = 'Ucraniano';
$strUncheckAll = 'Nenhum';
$strUnicode = 'Unicode';
$strUnique = 'nico';
$strUnknown = 'desconhecido';
$strUnselectAll = 'Limpa Todas as Seleces';
$strUpdComTab = 'Consulte a Documentao sobre como actualizar a Tabela Column_comments Table';
$strUpdatePrivMessage = 'Actualizou os privilgios de %s.';
$strUpdateProfileMessage = 'O prefil foi actualizado.';
$strUpdateQuery = 'Actualiza Comando SQL';
$strUpgrade = 'deve actualizar para %s %s ou mais recente.';
$strUsage = 'Utilizao';
$strUseBackquotes = 'Usar apstrofes com os nomes das tabelas e campos';
$strUseHostTable = 'Usar a tabela do anfitrio';
$strUseTables = 'Usar Tabelas';
$strUseTextField = 'Usar campo de texto';
$strUseThisValue = 'Usar este valor';
$strUser = 'Utilizador';
$strUserAlreadyExists = 'O utilizador %s j existe!';
$strUserEmpty = 'O nome do utilizador est vazio!';
$strUserName = 'Nome do Utilizador';
$strUserNotFound = 'O utilizador selecionado no se encontra na tabela de privilgios.';
$strUsersDeleted = 'Os utilizadores selecionado foram apagados com sucesso.';
$strUsersHavingAccessToDb = 'Utilizadores que tem acesso a &quot;%s&quot;';

$strValidateSQL = 'Validar SQL';
$strValue = 'Valor';
$strVar = 'Varivel';
$strViewDump = 'Ver o esquema da tabela';
$strViewDumpDB = 'Ver o esquema da base de dados';

$strWebServerUploadDirectory = 'Directoria no servidor web para fazer upload';
$strWebServerUploadDirectoryError = 'No  possivel alcanar a directoria que configurou para fazer upload';
$strWelcome = 'Bemvindo ao %s';
$strWestEuropean = 'Europeu de Oeste';
$strWithChecked = 'Com os seleccionados:';
$strWritingCommentNotPossible = 'No  possvel escrever comentrio';
$strWritingRelationNotPossible = 'No  possvel escrever relao';
$strWrongUser = 'Utilizador ou Palavra-passe errada. Acesso Negado.';

$strXML = 'XML';// (Same in portuguese)

$strYes = 'Sim';

$strZeroRemovesTheLimit = 'Nota: Configurar estas opes para 0 (zero) remove o limite.';
$strZip = '"Compresso zip"';

// To translate:

$strBeginCut = 'BEGIN CUT';  //to translate
$strBeginRaw = 'BEGIN RAW';  //to translate
$strBrowseForeignValues = 'Browse foreign values';  //to translate
$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this php version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a later php version. See php bug report %s for details.'; //to translate

$strCharsetsAndCollations = 'Character Sets and Collations';  //to translate
$strCheckOverhead = 'Check tables with overhead';  //to translate
$strCollation = 'Collation';  //to translate
$strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
$strCouldNotKill = 'phpMyAdmin was unable to kill thread %s. It probably has already been closed.'; //to translate
$strCyrillic = 'Cyrillic';  //to translate

$strDefaultValueHelp = 'For default values, please enter just a single value, without backslash escaping or quotes, using this format: a';  //to translate
$strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?';  //to translate
$strDelayedInserts = 'Use delayed inserts';  //to translate

$strEndCut = 'END CUT';  //to translate
$strEndRaw = 'END RAW';  //to translate

$strLatexLabel = 'Label key';//to translate

$strPrivDescLockTables = 'Allows locking tables for the current thread.'; //to translate
$strPrivDescReload = 'Allows reloading server settings and flushing the server\'s caches.'; //to translate
$strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.'; //to translate
$strPrivDescReplSlave = 'Needed for the replication slaves.'; //to translate
$strPrivDescSuper = 'Permite connectiong, even if maximum number of connections is reached; Required for most administrative operations like setting global variables or killing threads of other users.'; //to translate


$strThreadSuccessfullyKilled = 'Thread %s was successfully killed.'; //to translate
$strToggleScratchboard = 'toggle scratchboard';  //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
$strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';  //to translate
$strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .';//to translate

$strUserOverview = 'User overview'; //to translate

$strValidatorError = 'The SQL validator could not be initialized. Please check if you have installed the necessary php extensions as described in the %sdocumentation%s.'; //to translate
$strViewDumpDatabases = 'View dump (schema) of databases';//to translate

$strWildcard = 'wildcard';  //to translate
$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate

$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDBRename = 'Rename database to';  //to translate
$strOperator = 'Operator';  //to translate
$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strCalendar = 'Calendar';  //to translate
$strRefresh = 'Refresh';  //to translate
$strDefragment = 'Defragment table';  //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strSpanish = 'Spanish';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strTheme = 'Theme / Style';  //to translate
$strTakeIt = 'take it';  //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strIcelandic = 'Icelandic';  //to translate
$strLatvian = 'Latvian';  //to translate
$strPolish = 'Polish';  //to translate
$strRomanian = 'Romanian';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strSlovak = 'Slovak';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
